@@ -1,4 +1,19 @@
 # -*- coding: utf-8 -*-
+"""Tornado request argument parsing module.
+
+Example: ::
+
+    import tornado.web
+    from webargs import Arg
+    from webargs.tornadoparser import use_args
+
+    class HelloHandler(tornado.web.RequestHandler):
+
+        @use_args({'name': Arg(str)})
+        def get(self, args):
+            response = {'message': 'Hello {}'.format(args['name'])}
+            self.write(response)
+"""
 
 import json
 import functools
@@ -8,6 +23,26 @@ import tornado.web
 from webargs import core
 
 
+def parse_json(s):
+    if isinstance(s, bytes):
+        s = s.decode('utf-8')
+    return json.loads(s)
+
+def get_value(d, name, multiple):
+    """Handle gets from 'multidicts' made of lists
+
+    It handles cases: ``{"key": [value]}`` and ``{"key": value}``
+    """
+    value = d.get(name)
+
+    if multiple:
+        return [] if value is None else value
+
+    if value and isinstance(value, list):
+        return value[0]
+
+    return value
+
 class TornadoParser(core.Parser):
     """Tornado request argument parser."""
 
@@ -47,8 +82,9 @@ class TornadoParser(core.Parser):
         raise tornado.web.HTTPError(400, error)
 
     def _parse_json_body(self, req):
-        if req.headers.get('Content-Type') == 'application/json':
-            self.json = json.loads(req.body)
+        content_type = req.headers.get('Content-Type')
+        if content_type and 'application/json' in req.headers.get('Content-Type'):
+            self.json = parse_json(req.body)
         else:
             self.json = {}
 
@@ -64,16 +100,10 @@ class TornadoParser(core.Parser):
                 as_kwargs=False):
         """Decorator that injects parsed arguments into a view function or method.
 
-        Example: ::
-
-            @parser.use_kwargs({'name': Arg(type_=str)})
-            def myview(request, args):
-                self.write('Hello ' + args['name'])
-
         :param dict argmap: Dictionary of argument_name:Arg object pairs.
         :param req: The request object to parse
         :param tuple targets: Where on the request to search for values.
-        :param as_kwargs: Wether to pass arguments to the handler as kwargs
+        :param as_kwargs: Whether to pass arguments to the handler as kwargs
         """
         def decorator(func):
             @functools.wraps(func)
@@ -91,22 +121,6 @@ class TornadoParser(core.Parser):
         return decorator
 
 
-def get_value(d, name, multiple):
-    """Handle gets from 'multidicts' made of lists
-
-    It handles cases: ``{"key": [value]}`` and ``{"key": value}``
-    """
-    value = d.get(name)
-
-    if multiple:
-        return [] if value is None else value
-
-    if value and isinstance(value, list):
-        return value[0]
-
-    return value
-
-
 parser = TornadoParser()
 use_args = parser.use_args
 use_kwargs = parser.use_kwargs
